@@ -105,7 +105,7 @@ class RabbitMQService:
             )
 
             # 初始化连接池
-            await cls._connection_pool.init_pools()
+            await asyncio.wait_for(cls._connection_pool.init_pools(), timeout=30)
             logger.info("RabbitMQ连接池初始化成功")
 
         except Exception as e:
