@@ -199,6 +199,10 @@ class Services(metaclass=SingletonMeta):
                 if not sender:
                     raise ValueError(f"发送器 '{queue_name}' 不存在")
 
+                if not (sender.is_connected and sender.channel and not sender.channel.is_closed):
+                    logging.info(f"发送器 '{queue_name}' 连接无效，强制重连")
+                    await sender.connect(force_reconnect=True, declare_queue=False)
+
                 await RabbitMQService.send_message(data, queue_name, ** kwargs)
                 logging.info(f"消息发送成功（尝试 {attempt+1}/{max_retries}）")
                 return
